Splash Screen (splashscreen) — Orange Canvas Core 0.0.9 documentation

# Orange Canvas Core 0.0.9 documentation

## Splash Screen (splashscreen)

# Splash Screen (`splashscreen`)

A splash screen widget with support for positioning of the message text.

class `orangecanvas.gui.splashscreen.` `SplashScreen`(parent=None, pixmap=None, textRect=None, textFormat=0, **kwargs)

  Bases: `PyQt5.QtWidgets.QSplashScreen`

  Splash screen widget.

  Parameters: | parent (`QWidget`) – Parent widget pixmap (`QPixmap`) – Splash window pixmap. textRect (`QRect`) – Bounding rectangle of the shown message on the widget. textFormat (Qt.TextFormat) – How message text format should be interpreted.

  `setTextRect`(rect)

    Set the rectangle (`QRect`) in which to show the message text.

  `textRect`()

    Return the text message rectangle.

  `drawContents`(painter)

    Reimplementation of drawContents to limit the drawing inside textRext.

  `showMessage`(message, alignment=1, color=2)

    Show the message with color and alignment.